Welcome to mirror list, hosted at ThFree Co, Russian Federation.

gitlab.com/Remmina/Remmina.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAllan Nordhøy <epost@anotheragency.no>2021-12-03 12:01:36 +0300
committerAntenore Gatta (tmow) <antenore@simbiosi.org>2021-12-03 12:01:36 +0300
commitbfe3bbbb7eb19fcbb652b9e18cbbf343f2718211 (patch)
tree7d3e37cbd30e4420bab1c2788c25d3cd7584647d /src/remmina.c
parentcfbd68399785ecaf5ae6ba532ea64293cd2683ca (diff)
New debug strings reworked
Diffstat (limited to 'src/remmina.c')
-rw-r--r--src/remmina.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/remmina.c b/src/remmina.c
index cbce50a65..e0eba489a 100644
--- a/src/remmina.c
+++ b/src/remmina.c
@@ -87,9 +87,9 @@ static GOptionEntry remmina_options[] =
// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
{ "connect", 'c', 0, G_OPTION_ARG_FILENAME_ARRAY, NULL, N_("Connect either to a desktop described in a file (.remmina or a filetype supported by a plugin) or a supported URI (RDP, VNC, SSH or SPICE)"), N_("FILE") },
// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
- { G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, NULL, N_("Connect to a desktop described in a file (.remmina or a type supported by a plugin)"), N_("FILE") },
+ { G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, NULL, N_("Connect to a desktop described in a file (.remmina or a filetype supported by a plugin)"), N_("FILE") },
// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
- { "edit", 'e', 0, G_OPTION_ARG_FILENAME_ARRAY, NULL, N_("Edit desktop connection described in file (.remmina or type supported by plugin)"), N_("FILE") },
+ { "edit", 'e', 0, G_OPTION_ARG_FILENAME_ARRAY, NULL, N_("Edit desktop connection described in file (.remmina or a filetype supported by plugin)"), N_("FILE") },
{ "help", '?', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, NULL, NULL, NULL },
// TRANSLATORS: Shown in terminal. Do not use characters that may be not supported on a terminal
{ "kiosk", 'k', 0, G_OPTION_ARG_NONE, NULL, N_("Start in kiosk mode"), NULL },
@@ -328,16 +328,16 @@ int main(int argc, char *argv[])
// Checking for environment variable "G_MESSAGES_DEBUG"
// Give the less familiar with GLib a tip on where to get
// more debugging information.
if(!getenv("G_MESSAGES_DEBUG")) {
/* TRANSLATORS:
* This link should point to a resource explaining how to get Remmina
* to log more verbose statements.
*/
- g_message(_("Remmina does not log all output statements. To enable a "
- "more verbose output please use G_MESSAGES_DEBUG=all as an "
- "environment variable.\n"
- "For more information, please visit the Remmina Wiki at:\n"
+ g_message(_("Remmina does not log all output statements. "
+ "Turn on more verbose output by using "
+ "\"G_MESSAGES_DEBUG=all\" as an environment variable.\n"
+ "More info available on the Remmina wiki at:\n"
"https://gitlab.com/Remmina/Remmina/-/wikis/Usage/Remmina-debugging"
));
}
@@ -328,16 +328,16 @@ int main(int argc, char *argv[])
// Checking for environment variable "G_MESSAGES_DEBUG"
// Give the less familiar with GLib a tip on where to get
- // more debugging information.
+ // more debugging info.
if(!getenv("G_MESSAGES_DEBUG")) {
/* TRANSLATORS: